@@ -256,6 +256,7 @@ if __name__ == '__main__':
     from spider.elements.map import Lane
     from spider.elements.vehicle import *
     from spider.elements.Box import obb2vertices
+    import spider.visualize as vis
     import matplotlib.pyplot as plt
     import cv2
 
@@ -299,6 +300,9 @@ if __name__ == '__main__':
             video_name = 'test_mfrl_50000.mp4'
             video_writer = None
 
+        plt.figure(figsize=(14, 4))
+        plt.axis('equal')
+        plt.tight_layout()
         ################## main loop ########################
         while True:
             if ego_veh_state.x() > 160: break
@@ -319,18 +323,40 @@ if __name__ == '__main__':
             # 可视化
             plt.cla()
             for lane in local_map.lanes:
-                plt.plot(lane.centerline[:,0], lane.centerline[:,1], color='gray', linestyle='--', lw= 1.5) # 画地图
-            vertices = obb2vertices([ego_veh_state.x(), ego_veh_state.y(),5.,2.,ego_veh_state.yaw()])
-            vertices = np.vstack((vertices, vertices[0]))  # recurrent to close polyline
-            plt.plot(vertices[:, 0], vertices[:, 1], color='blue', linestyle='-', linewidth=1.5) # 画自车
+                plt.plot(lane.centerline[:, 0], lane.centerline[:, 1], color='gray', linestyle='--', lw=1.5)  # 画地图
+            # vis.draw_ego_vehicle(ego_veh_state, color='green', fill=True, alpha=0.2, linestyle='-', linewidth=1.5) # 画自车
+
             for tb in tb_list:
-                vertices = tb.vertices
-                vertices = np.vstack((vertices, vertices[0]))  # recurrent to close polyline
-                plt.plot(vertices[:, 0], vertices[:, 1], color='black', linestyle='-', linewidth=1.5)  # 画他车
-            plt.plot(traj.x,traj.y,'r-.',lw=1) # 画轨迹
-            plt.axis('equal')
-            plt.xlim([ego_veh_state.x()-5, ego_veh_state.x()+100])
-            plt.ylim([ego_veh_state.y()-5,ego_veh_state.y()+5])
+                vis.draw_boundingbox(tb, color='black', fill=True, alpha=0.1, linestyle='-', linewidth=1.5)  # 画他车
+                # 画他车预测轨迹
+                tb_pred_traj = np.column_stack((tb.x + traj.t * tb.vx, tb.y + traj.t * tb.vy))
+                vis.draw_polyline(tb_pred_traj, show_buffer=True, buffer_dist=tb.width * 0.5, buffer_alpha=0.1,
+                                  color='C3')
+
+            vis.draw_ego_history(ego_veh_state, '-', lw=1, color='gray')  # 画自车历史
+            vis.draw_trajectory(traj, '.-', show_footprint=True, color='C2')  # 画轨迹
+            if "control_points" in traj.debug_info:
+                pts = traj.debug_info["control_points"]
+                plt.plot(pts[:, 0], pts[:, 1], 'or')
+            vis.draw_ego_vehicle(ego_veh_state, color='C0', fill=True, alpha=0.3, linestyle='-',
+                                 linewidth=1.5)  # 画自车
+            # plt.axis('equal')
+            # plt.tight_layout()
+            vis.ego_centric_view(ego_veh_state.x(),ego_veh_state.y(), [-20, 80], [-5, 5])
+            # plt.cla()
+            # for lane in local_map.lanes:
+            #     plt.plot(lane.centerline[:,0], lane.centerline[:,1], color='gray', linestyle='--', lw= 1.5) # 画地图
+            # vertices = obb2vertices([ego_veh_state.x(), ego_veh_state.y(),5.,2.,ego_veh_state.yaw()])
+            # vertices = np.vstack((vertices, vertices[0]))  # recurrent to close polyline
+            # plt.plot(vertices[:, 0], vertices[:, 1], color='blue', linestyle='-', linewidth=1.5) # 画自车
+            # for tb in tb_list:
+            #     vertices = tb.vertices
+            #     vertices = np.vstack((vertices, vertices[0]))  # recurrent to close polyline
+            #     plt.plot(vertices[:, 0], vertices[:, 1], color='black', linestyle='-', linewidth=1.5)  # 画他车
+            # plt.plot(traj.x,traj.y,'r-.',lw=1) # 画轨迹
+            # plt.axis('equal')
+            # plt.xlim([ego_veh_state.x()-5, ego_veh_state.x()+100])
+            # plt.ylim([ego_veh_state.y()-5,ego_veh_state.y()+5])
             plt.pause(0.01)
             # 将Matplotlib图形保存为图像
             if save_video:
